---
title: The Pond in Winter
id: the-pond-in-winter
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 16
category: pond
kind: article
---

## The Pond in Winter

After a still winter night I awoke with the impression that some
question had been put to me, which I had been endeavoring in vain to
answer in my sleep, as what—how—when—where? But there was dawning
Nature, in whom all creatures live, looking in at my broad windows with
serene and satisfied face, and no question on _her_ lips. I awoke to an
answered question, to Nature and daylight. The snow lying deep on the
earth dotted with young pines, and the very slope of the hill on which
my house is placed, seemed to say, Forward! Nature puts no question and
answers none which we mortals ask. She has long ago taken her
resolution. “O Prince, our eyes contemplate with admiration and
transmit to the soul the wonderful and varied spectacle of this
universe. The night veils without doubt a part of this glorious
creation; but day comes to reveal to us this great work, which extends
from earth even into the plains of the ether.”

Then to my morning work. First I take an axe and pail and go in search
of water, if that be not a dream. After a cold and snowy night it
needed a divining rod to find it. Every winter the liquid and trembling
surface of the pond, which was so sensitive to every breath, and
reflected every light and shadow, becomes solid to the depth of a foot
or a foot and a half, so that it will support the heaviest teams, and
perchance the snow covers it to an equal depth, and it is not to be
distinguished from any level field. Like the marmots in the surrounding
hills, it closes its eye-lids and becomes dormant for three months or
more. Standing on the snow-covered plain, as if in a pasture amid the
hills, I cut my way first through a foot of snow, and then a foot of
ice, and open a window under my feet, where, kneeling to drink, I look
down into the quiet parlor of the fishes, pervaded by a softened light
as through a window of ground glass, with its bright sanded floor the
same as in summer; there a perennial waveless serenity reigns as in the
amber twilight sky, corresponding to the cool and even temperament of
the inhabitants. Heaven is under our feet as well as over our heads.

Early in the morning, while all things are crisp with frost, men come
with fishing reels and slender lunch, and let down their fine lines
through the snowy field to take pickerel and perch; wild men, who
instinctively follow other fashions and trust other authorities than
their townsmen, and by their goings and comings stitch towns together
in parts where else they would be ripped. They sit and eat their
luncheon in stout fear-naughts on the dry oak leaves on the shore, as
wise in natural lore as the citizen is in artificial. They never
consulted with books, and know and can tell much less than they have
done. The things which they practise are said not yet to be known. Here
is one fishing for pickerel with grown perch for bait. You look into
his pail with wonder as into a summer pond, as if he kept summer locked
up at home, or knew where she had retreated. How, pray, did he get
these in mid-winter? O, he got worms out of rotten logs since the
ground froze, and so he caught them. His life itself passes deeper in
Nature than the studies of the naturalist penetrate; himself a subject
for the naturalist. The latter raises the moss and bark gently with his
knife in search of insects; the former lays open logs to their core
with his axe, and moss and bark fly far and wide. He gets his living by
barking trees. Such a man has some right to fish, and I love to see
Nature carried out in him. The perch swallows the grub-worm, the
pickerel swallows the perch, and the fisher-man swallows the pickerel;
and so all the chinks in the scale of being are filled.

When I strolled around the pond in misty weather I was sometimes amused
by the primitive mode which some ruder fisherman had adopted. He would
perhaps have placed alder branches over the narrow holes in the ice,
which were four or five rods apart and an equal distance from the
shore, and having fastened the end of the line to a stick to prevent
its being pulled through, have passed the slack line over a twig of the
alder, a foot or more above the ice, and tied a dry oak leaf to it,
which, being pulled down, would show when he had a bite. These alders
loomed through the mist at regular intervals as you walked half way
round the pond.

Ah, the pickerel of Walden! when I see them lying on the ice, or in the
well which the fisherman cuts in the ice, making a little hole to admit
the water, I am always surprised by their rare beauty, as if they were
fabulous fishes, they are so foreign to the streets, even to the woods,
foreign as Arabia to our Concord life. They possess a quite dazzling
and transcendent beauty which separates them by a wide interval from
the cadaverous cod and haddock whose fame is trumpeted in our streets.
They are not green like the pines, nor gray like the stones, nor blue
like the sky; but they have, to my eyes, if possible, yet rarer colors,
like flowers and precious stones, as if they were the pearls, the
animalized _nuclei_ or crystals of the Walden water. They, of course,
are Walden all over and all through; are themselves small Waldens in
the animal kingdom, Waldenses. It is surprising that they are caught
here,—that in this deep and capacious spring, far beneath the rattling
teams and chaises and tinkling sleighs that travel the Walden road,
this great gold and emerald fish swims. I never chanced to see its kind
in any market; it would be the cynosure of all eyes there. Easily, with
a few convulsive quirks, they give up their watery ghosts, like a
mortal translated before his time to the thin air of heaven.



walden_pond_map



As I was desirous to recover the long lost bottom of Walden Pond, I
surveyed it carefully, before the ice broke up, early in ’46, with
compass and chain and sounding line. There have been many stories told
about the bottom, or rather no bottom, of this pond, which certainly
had no foundation for themselves. It is remarkable how long men will
believe in the bottomlessness of a pond without taking the trouble to
sound it. I have visited two such Bottomless Ponds in one walk in this
neighborhood. Many have believed that Walden reached quite through to
the other side of the globe. Some who have lain flat on the ice for a
long time, looking down through the illusive medium, perchance with
watery eyes into the bargain, and driven to hasty conclusions by the
fear of catching cold in their breasts, have seen vast holes “into
which a load of hay might be driven,” if there were any body to drive
it, the undoubted source of the Styx and entrance to the Infernal
Regions from these parts. Others have gone down from the village with a
“fifty-six” and a wagon load of inch rope, but yet have failed to find
any bottom; for while the “fifty-six” was resting by the way, they were
paying out the rope in the vain attempt to fathom their truly
immeasurable capacity for marvellousness. But I can assure my readers
that Walden has a reasonably tight bottom at a not unreasonable, though
at an unusual, depth. I fathomed it easily with a cod-line and a stone
weighing about a pound and a half, and could tell accurately when the
stone left the bottom, by having to pull so much harder before the
water got underneath to help me. The greatest depth was exactly one
hundred and two feet; to which may be added the five feet which it has
risen since, making one hundred and seven. This is a remarkable depth
for so small an area; yet not an inch of it can be spared by the
imagination. What if all ponds were shallow? Would it not react on the
minds of men? I am thankful that this pond was made deep and pure for a
symbol. While men believe in the infinite some ponds will be thought to
be bottomless.

A factory owner, hearing what depth I had found, thought that it could
not be true, for, judging from his acquaintance with dams, sand would
not lie at so steep an angle. But the deepest ponds are not so deep in
proportion to their area as most suppose, and, if drained, would not
leave very remarkable valleys. They are not like cups between the
hills; for this one, which is so unusually deep for its area, appears
in a vertical section through its centre not deeper than a shallow
plate. Most ponds, emptied, would leave a meadow no more hollow than we
frequently see. William Gilpin, who is so admirable in all that relates
to landscapes, and usually so correct, standing at the head of Loch
Fyne, in Scotland, which he describes as “a bay of salt water, sixty or
seventy fathoms deep, four miles in breadth,” and about fifty miles
long, surrounded by mountains, observes, “If we could have seen it
immediately after the diluvian crash, or whatever convulsion of Nature
occasioned it, before the waters gushed in, what a horrid chasm must it
have appeared!

     So high as heaved the tumid hills, so low
     Down sunk a hollow bottom broad and deep,
     Capacious bed of waters—.”

But if, using the shortest diameter of Loch Fyne, we apply these
proportions to Walden, which, as we have seen, appears already in a
vertical section only like a shallow plate, it will appear four times
as shallow. So much for the _increased_ horrors of the chasm of Loch
Fyne when emptied. No doubt many a smiling valley with its stretching
cornfields occupies exactly such a “horrid chasm,” from which the
waters have receded, though it requires the insight and the far sight
of the geologist to convince the unsuspecting inhabitants of this fact.
Often an inquisitive eye may detect the shores of a primitive lake in
the low horizon hills, and no subsequent elevation of the plain has
been necessary to conceal their history. But it is easiest, as they who
work on the highways know, to find the hollows by the puddles after a
shower. The amount of it is, the imagination give it the least license,
dives deeper and soars higher than Nature goes. So, probably, the depth
of the ocean will be found to be very inconsiderable compared with its
breadth.

As I sounded through the ice I could determine the shape of the bottom
with greater accuracy than is possible in surveying harbors which do
not freeze over, and I was surprised at its general regularity. In the
deepest part there are several acres more level than almost any field
which is exposed to the sun wind and plough. In one instance, on a line
arbitrarily chosen, the depth did not vary more than one foot in thirty
rods; and generally, near the middle, I could calculate the variation
for each one hundred feet in any direction beforehand within three or
four inches. Some are accustomed to speak of deep and dangerous holes
even in quiet sandy ponds like this, but the effect of water under
these circumstances is to level all inequalities. The regularity of the
bottom and its conformity to the shores and the range of the
neighboring hills were so perfect that a distant promontory betrayed
itself in the soundings quite across the pond, and its direction could
be determined by observing the opposite shore. Cape becomes bar, and
plain shoal, and valley and gorge deep water and channel.

When I had mapped the pond by the scale of ten rods to an inch, and put
down the soundings, more than a hundred in all, I observed this
remarkable coincidence. Having noticed that the number indicating the
greatest depth was apparently in the centre of the map, I laid a rule
on the map lengthwise, and then breadthwise, and found, to my surprise,
that the line of greatest length intersected the line of greatest
breadth _exactly_ at the point of greatest depth, notwithstanding that
the middle is so nearly level, the outline of the pond far from
regular, and the extreme length and breadth were got by measuring into
the coves; and I said to myself, Who knows but this hint would conduct
to the deepest part of the ocean as well as of a pond or puddle? Is not
this the rule also for the height of mountains, regarded as the
opposite of valleys? We know that a hill is not highest at its
narrowest part.

Of five coves, three, or all which had been sounded, were observed to
have a bar quite across their mouths and deeper water within, so that
the bay tended to be an expansion of water within the land not only
horizontally but vertically, and to form a basin or independent pond,
the direction of the two capes showing the course of the bar. Every
harbor on the sea-coast, also, has its bar at its entrance. In
proportion as the mouth of the cove was wider compared with its length,
the water over the bar was deeper compared with that in the basin.
Given, then, the length and breadth of the cove, and the character of
the surrounding shore, and you have almost elements enough to make out
a formula for all cases.

In order to see how nearly I could guess, with this experience, at the
deepest point in a pond, by observing the outlines of its surface and
the character of its shores alone, I made a plan of White Pond, which
contains about forty-one acres, and, like this, has no island in it,
nor any visible inlet or outlet; and as the line of greatest breadth
fell very near the line of least breadth, where two opposite capes
approached each other and two opposite bays receded, I ventured to mark
a point a short distance from the latter line, but still on the line of
greatest length, as the deepest. The deepest part was found to be
within one hundred feet of this, still farther in the direction to
which I had inclined, and was only one foot deeper, namely, sixty feet.
Of course, a stream running through, or an island in the pond, would
make the problem much more complicated.

If we knew all the laws of Nature, we should need only one fact, or the
description of one actual phenomenon, to infer all the particular
results at that point. Now we know only a few laws, and our result is
vitiated, not, of course, by any confusion or irregularity in Nature,
but by our ignorance of essential elements in the calculation. Our
notions of law and harmony are commonly confined to those instances
which we detect; but the harmony which results from a far greater
number of seemingly conflicting, but really concurring, laws, which we
have not detected, is still more wonderful. The particular laws are as
our points of view, as, to the traveller, a mountain outline varies
with every step, and it has an infinite number of profiles, though
absolutely but one form. Even when cleft or bored through it is not
comprehended in its entireness.

What I have observed of the pond is no less true in ethics. It is the
law of average. Such a rule of the two diameters not only guides us
toward the sun in the system and the heart in man, but draw lines
through the length and breadth of the aggregate of a man’s particular
daily behaviors and waves of life into his coves and inlets, and where
they intersect will be the height or depth of his character. Perhaps we
need only to know how his shores trend and his adjacent country or
circumstances, to infer his depth and concealed bottom. If he is
surrounded by mountainous circumstances, an Achillean shore, whose
peaks overshadow and are reflected in his bosom, they suggest a
corresponding depth in him. But a low and smooth shore proves him
shallow on that side. In our bodies, a bold projecting brow falls off
to and indicates a corresponding depth of thought. Also there is a bar
across the entrance of our every cove, or particular inclination; each
is our harbor for a season, in which we are detained and partially
land-locked. These inclinations are not whimsical usually, but their
form, size, and direction are determined by the promontories of the
shore, the ancient axes of elevation. When this bar is gradually
increased by storms, tides, or currents, or there is a subsidence of
the waters, so that it reaches to the surface, that which was at first
but an inclination in the shore in which a thought was harbored becomes
an individual lake, cut off from the ocean, wherein the thought secures
its own conditions, changes, perhaps, from salt to fresh, becomes a
sweet sea, dead sea, or a marsh. At the advent of each individual into
this life, may we not suppose that such a bar has risen to the surface
somewhere? It is true, we are such poor navigators that our thoughts,
for the most part, stand off and on upon a harborless coast, are
conversant only with the bights of the bays of poesy, or steer for the
public ports of entry, and go into the dry docks of science, where they
merely refit for this world, and no natural currents concur to
individualize them.

As for the inlet or outlet of Walden, I have not discovered any but
rain and snow and evaporation, though perhaps, with a thermometer and a
line, such places may be found, for where the water flows into the pond
it will probably be coldest in summer and warmest in winter. When the
ice-men were at work here in ’46–7, the cakes sent to the shore were
one day rejected by those who were stacking them up there, not being
thick enough to lie side by side with the rest; and the cutters thus
discovered that the ice over a small space was two or three inches
thinner than elsewhere, which made them think that there was an inlet
there. They also showed me in another place what they thought was a
“leach hole,” through which the pond leaked out under a hill into a
neighboring meadow, pushing me out on a cake of ice to see it. It was a
small cavity under ten feet of water; but I think that I can warrant
the pond not to need soldering till they find a worse leak than that.
One has suggested, that if such a “leach hole” should be found, its
connection with the meadow, if any existed, might be proved by
conveying some colored powder or sawdust to the mouth of the hole, and
then putting a strainer over the spring in the meadow, which would
catch some of the particles carried through by the current.

While I was surveying, the ice, which was sixteen inches thick,
undulated under a slight wind like water. It is well known that a level
cannot be used on ice. At one rod from the shore its greatest
fluctuation, when observed by means of a level on land directed toward
a graduated staff on the ice, was three quarters of an inch, though the
ice appeared firmly attached to the shore. It was probably greater in
the middle. Who knows but if our instruments were delicate enough we
might detect an undulation in the crust of the earth? When two legs of
my level were on the shore and the third on the ice, and the sights
were directed over the latter, a rise or fall of the ice of an almost
infinitesimal amount made a difference of several feet on a tree across
the pond. When I began to cut holes for sounding, there were three or
four inches of water on the ice under a deep snow which had sunk it
thus far; but the water began immediately to run into these holes, and
continued to run for two days in deep streams, which wore away the ice
on every side, and contributed essentially, if not mainly, to dry the
surface of the pond; for, as the water ran in, it raised and floated
the ice. This was somewhat like cutting a hole in the bottom of a ship
to let the water out. When such holes freeze, and a rain succeeds, and
finally a new freezing forms a fresh smooth ice over all, it is
beautifully mottled internally by dark figures, shaped somewhat like a
spider’s web, what you may call ice rosettes, produced by the channels
worn by the water flowing from all sides to a centre. Sometimes, also,
when the ice was covered with shallow puddles, I saw a double shadow of
myself, one standing on the head of the other, one on the ice, the
other on the trees or hill-side.



While yet it is cold January, and snow and ice are thick and solid, the
prudent landlord comes from the village to get ice to cool his summer
drink; impressively, even pathetically wise, to foresee the heat and
thirst of July now in January,—wearing a thick coat and mittens! when
so many things are not provided for. It may be that he lays up no
treasures in this world which will cool his summer drink in the next.
He cuts and saws the solid pond, unroofs the house of fishes, and carts
off their very element and air, held fast by chains and stakes like
corded wood, through the favoring winter air, to wintry cellars, to
underlie the summer there. It looks like solidified azure, as, far off,
it is drawn through the streets. These ice-cutters are a merry race,
full of jest and sport, and when I went among them they were wont to
invite me to saw pit-fashion with them, I standing underneath.

In the winter of ’46–7 there came a hundred men of Hyperborean
extraction swoop down on to our pond one morning, with many car-loads
of ungainly-looking farming tools, sleds, ploughs, drill-barrows,
turf-knives, spades, saws, rakes, and each man was armed with a
double-pointed pike-staff, such as is not described in the New-England
Farmer or the Cultivator. I did not know whether they had come to sow a
crop of winter rye, or some other kind of grain recently introduced
from Iceland. As I saw no manure, I judged that they meant to skim the
land, as I had done, thinking the soil was deep and had lain fallow
long enough. They said that a gentleman farmer, who was behind the
scenes, wanted to double his money, which, as I understood, amounted to
half a million already; but in order to cover each one of his dollars
with another, he took off the only coat, ay, the skin itself, of Walden
Pond in the midst of a hard winter. They went to work at once,
ploughing, harrowing, rolling, furrowing, in admirable order, as if
they were bent on making this a model farm; but when I was looking
sharp to see what kind of seed they dropped into the furrow, a gang of
fellows by my side suddenly began to hook up the virgin mould itself,
with a peculiar jerk, clean down to the sand, or rather the water,—for
it was a very springy soil,—indeed all the _terra firma_ there was,—and
haul it away on sleds, and then I guessed that they must be cutting
peat in a bog. So they came and went every day, with a peculiar shriek
from the locomotive, from and to some point of the polar regions, as it
seemed to me, like a flock of arctic snow-birds. But sometimes Squaw
Walden had her revenge, and a hired man, walking behind his team,
slipped through a crack in the ground down toward Tartarus, and he who
was so brave before suddenly became but the ninth part of a man, almost
gave up his animal heat, and was glad to take refuge in my house, and
acknowledged that there was some virtue in a stove; or sometimes the
frozen soil took a piece of steel out of a ploughshare, or a plough got
set in the furrow and had to be cut out.

To speak literally, a hundred Irishmen, with Yankee overseers, came
from Cambridge every day to get out the ice. They divided it into cakes
by methods too well known to require description, and these, being
sledded to the shore, were rapidly hauled off on to an ice platform,
and raised by grappling irons and block and tackle, worked by horses,
on to a stack, as surely as so many barrels of flour, and there placed
evenly side by side, and row upon row, as if they formed the solid base
of an obelisk designed to pierce the clouds. They told me that in a
good day they could get out a thousand tons, which was the yield of
about one acre. Deep ruts and “cradle holes” were worn in the ice, as
on _terra firma_, by the passage of the sleds over the same track, and
the horses invariably ate their oats out of cakes of ice hollowed out
like buckets. They stacked up the cakes thus in the open air in a pile
thirty-five feet high on one side and six or seven rods square, putting
hay between the outside layers to exclude the air; for when the wind,
though never so cold, finds a passage through, it will wear large
cavities, leaving slight supports or studs only here and there, and
finally topple it down. At first it looked like a vast blue fort or
Valhalla; but when they began to tuck the coarse meadow hay into the
crevices, and this became covered with rime and icicles, it looked like
a venerable moss-grown and hoary ruin, built of azure-tinted marble,
the abode of Winter, that old man we see in the almanac,—his shanty, as
if he had a design to estivate with us. They calculated that not
twenty-five per cent of this would reach its destination, and that two
or three per cent would be wasted in the cars. However, a still greater
part of this heap had a different destiny from what was intended; for,
either because the ice was found not to keep so well as was expected,
containing more air than usual, or for some other reason, it never got
to market. This heap, made in the winter of ’46–7 and estimated to
contain ten thousand tons, was finally covered with hay and boards; and
though it was unroofed the following July, and a part of it carried
off, the rest remaining exposed to the sun, it stood over that summer
and the next winter, and was not quite melted till September 1848. Thus
the pond recovered the greater part.

Like the water, the Walden ice, seen near at hand, has a green tint,
but at a distance is beautifully blue, and you can easily tell it from
the white ice of the river, or the merely greenish ice of some ponds, a
quarter of a mile off. Sometimes one of those great cakes slips from
the ice-man’s sled into the village street, and lies there for a week
like a great emerald, an object of interest to all passers. I have
noticed that a portion of Walden which in the state of water was green
will often, when frozen, appear from the same point of view blue. So
the hollows about this pond will, sometimes, in the winter, be filled
with a greenish water somewhat like its own, but the next day will have
frozen blue. Perhaps the blue color of water and ice is due to the
light and air they contain, and the most transparent is the bluest. Ice
is an interesting subject for contemplation. They told me that they had
some in the ice-houses at Fresh Pond five years old which was as good
as ever. Why is it that a bucket of water soon becomes putrid, but
frozen remains sweet forever? It is commonly said that this is the
difference between the affections and the intellect.

Thus for sixteen days I saw from my window a hundred men at work like
busy husbandmen, with teams and horses and apparently all the
implements of farming, such a picture as we see on the first page of
the almanac; and as often as I looked out I was reminded of the fable
of the lark and the reapers, or the parable of the sower, and the like;
and now they are all gone, and in thirty days more, probably, I shall
look from the same window on the pure sea-green Walden water there,
reflecting the clouds and the trees, and sending up its evaporations in
solitude, and no traces will appear that a man has ever stood there.
Perhaps I shall hear a solitary loon laugh as he dives and plumes
himself, or shall see a lonely fisher in his boat, like a floating
leaf, beholding his form reflected in the waves, where lately a hundred
men securely labored.

Thus it appears that the sweltering inhabitants of Charleston and New
Orleans, of Madras and Bombay and Calcutta, drink at my well. In the
morning I bathe my intellect in the stupendous and cosmogonal
philosophy of the Bhagvat Geeta, since whose composition years of the
gods have elapsed, and in comparison with which our modern world and
its literature seem puny and trivial; and I doubt if that philosophy is
not to be referred to a previous state of existence, so remote is its
sublimity from our conceptions. I lay down the book and go to my well
for water, and lo! there I meet the servant of the Bramin, priest of
Brahma and Vishnu and Indra, who still sits in his temple on the Ganges
reading the Vedas, or dwells at the root of a tree with his crust and
water jug. I meet his servant come to draw water for his master, and
our buckets as it were grate together in the same well. The pure Walden
water is mingled with the sacred water of the Ganges. With favoring
winds it is wafted past the site of the fabulous islands of Atlantis
and the Hesperides, makes the periplus of Hanno, and, floating by
Ternate and Tidore and the mouth of the Persian Gulf, melts in the
tropic gales of the Indian seas, and is landed in ports of which
Alexander only heard the names.


